'use strict';

const AWS = require('aws-sdk');

const SNS = new AWS.SNS();

function Emitter (options, query, callback) {
  options = options || {};
  if (!options.topic) {
    throw new Error('topic option must be defined');
  }

  function emit (type, data, cb) {
    const payload = {
      id: query.id,
      provider: options.name,
      type: type
    };
    if (data) {
      payload.data = data;
    }
    console.log('Emitting result');
    console.log(payload);
    cb = cb || function () {};
    SNS.publish({
      TopicArn: options.topic,
      Message: JSON.stringify(payload),
      MessageStructure: 'json'
    }, (err, response) => {
      if (err) {
        console.log('SNS error');
        console.log(err);
      } else {
        console.log('Sent SNS');
      }
      cb(err, response);
    });
  }

  return {
    result: (result) => {
      emit('result', result);
    },
    end: () => {
      emit('end', null, () => { callback(); });
    }
  };
}

module.exports = Emitter;
